#ifndef NT2_INCLUDE_FUNCTIONS_ABS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ABS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/abs.hpp>

#endif
